@@ -157,6 +157,8 @@ if [ -e /etc/fedora-release ]; then
     sed -i -e 's/if cached_client is None:/if cached_client is None or cached_client.opts["cachedir"] != self.opts["cachedir"]:/' \\
         -e 's/not hasattr(cached_client, "opts")/\\0 or cached_client.opts["cachedir"] != self.opts["cachedir"]/' \\
             /usr/lib/python3*/site-packages/salt/utils/jinja.py
+    sed -i -e 's/self.functions = salt.loader.ssh_wrapper.*/self.functions = self.wrapper/' \\
+            /usr/lib/python3*/site-packages/salt/client/ssh/state.py
 fi
 """
             fixup_proc = dispvm.run_service('qubes.VMRootShell', user='root')
